@@ -30,18 +30,15 @@
 
 class cthd_engine_default: public cthd_engine {
 private:
-	int parser_init();
-	void parser_deinit();
 	int add_replace_cdev(cooling_dev_t *config);
 
-	bool parser_init_done;
 	cthd_cpu_default_binding def_binding;
 
 public:
 	static const int power_clamp_reduction_percent = 5;
 
 	cthd_engine_default() :
-			cthd_engine(), parser_init_done(false) {
+			cthd_engine() {
 	}
 	~cthd_engine_default();
 	int read_thermal_zones();
@@ -50,6 +47,5 @@ public:
 };
 
 int thd_engine_create_default_engine(bool ignore_cpuid_check,
-		bool exclusive_control);
-
+		bool exclusive_control, const char *config_file);
 #endif /* THD_ENGINE_DEFAULT_H_ */
